@@ -42,7 +42,7 @@ class Pattern(NewReferenceObject, Directionable):
         self.reset()
 
     def get_octave_shift(self, track):
-        return track.instrument.base_octave + self.octave_shift
+        return self.octave_shift
 
     def get_length(self):
         return self.length
