@@ -70,7 +70,7 @@ class Transform(NewReferenceObject, Directionable):
             direction = data.get('direction',FORWARD)
         )
 
-    def process(self, song, scale, track, note_list, t_start, slot_duration):
+    def process(self, song, pattern, scale, track, note_list, t_start, slot_duration):
 
 
         """
@@ -82,6 +82,7 @@ class Transform(NewReferenceObject, Directionable):
 
         self._mod.scale = scale
         self._mod.track = track
+        self._mod.pattern = pattern
 
         assert song is not None
         self._mod.song = song
